@@ -158,7 +158,7 @@
 #define dlacpy_ dlacpy
 #endif
 #define Clacpy Cdgelacpy
-void  Clacpy();
+void  Clacpy(int, int, double*, int, double*, int);
 typedef struct {
   int   desctype;
   int   ctxt;
@@ -186,48 +186,48 @@ typedef struct {
 #define realloc myrealloc
 #endif
 /* Cblacs */
-extern void Cblacs_pcoord();
-extern int Cblacs_pnum();
-extern void Csetpvmtids();
-extern void Cblacs_get();
-extern void Cblacs_pinfo();
-extern void Cblacs_gridinfo();
-extern void Cblacs_gridinit();
-extern void Cblacs_exit();
-extern void Cblacs_gridexit();
-extern void Cblacs_setup();
-extern void Cigebs2d();
-extern void Cigebr2d();
-extern void Cigesd2d();
-extern void Cigerv2d();
-extern void Cigsum2d();
-extern void Cigamn2d();
-extern void Cigamx2d();
-extern void Cdgesd2d();
-extern void Cdgerv2d();
+extern void Cblacs_pcoord(int, int, int*, int*);
+extern int Cblacs_pnum(int, int, int);
+extern void Csetpvmtids(void);
+extern void Cblacs_get(int, int, int*);
+extern void Cblacs_pinfo(int*, int*);
+extern void Cblacs_gridinfo(int, int*, int*, int*, int*);
+extern void Cblacs_gridinit(int*, char*, int, int);
+extern void Cblacs_exit(int);
+extern void Cblacs_gridexit(int);
+extern void Cblacs_setup(int*, int*);
+extern void Cigebs2d(int, char*, char*, int, int, int*, int);
+extern void Cigebr2d(int, char*, char*, int, int, int*, int, int, int);
+extern void Cigesd2d(int, int, int, int*, int, int, int);
+extern void Cigerv2d(int, int, int, int*, int, int, int);
+extern void Cigsum2d(int, char*, char*, int, int, int*, int, int, int);
+extern void Cigamn2d(int, char*, char*, int, int, int*, int, int*, int*, int, int, int);
+extern void Cigamx2d(int, char*, char*, int, int, int*, int, int*, int*, int, int, int);
+extern void Cdgesd2d(int, int, int, double*, int, int, int);
+extern void Cdgerv2d(int, int, int, double*, int, int, int);
 /* lapack */
-void  dlacpy_();
+void  dlacpy_(const char*, const int*, const int*, const double*, const int*, double*, const int*);
 /* aux fonctions */
-extern int localindice();
-extern void *mr2d_malloc();
-extern int ppcm();
-extern int localsize();
-extern int memoryblocksize();
-extern int changeorigin();
-extern void paramcheck();
+extern int localindice(int, int, int, int, MDESC*);
+extern void *mr2d_malloc(long int);
+extern int ppcm(int, int);
+extern int localsize(int, int, int, int);
+extern int memoryblocksize(MDESC*);
+extern int changeorigin(int, int, int, int, int, int*, int*);
+extern void paramcheck(MDESC*, int, int, int, int, int, int, int);
 /* tools and others function */
 #define scanD0 dgescanD0
 #define dispmat dgedispmat
 #define setmemory dgesetmemory
 #define freememory dgefreememory
 #define scan_intervals dgescan_intervals
-extern void scanD0();
-extern void dispmat();
-extern void setmemory();
-extern void freememory();
-extern int scan_intervals();
-extern void Cpdgemr2do();
-extern void Cpdgemr2d();
+extern void scanD0(char*, char*, int, double*, int*, int, int, MDESC*, int, int, int, int, MDESC*, int, int, int, int, IDESC*, int, IDESC*, int, double*);
+extern void dispmat(void);
+extern void setmemory(double**, int);
+extern void freememory(double*);
+extern int scan_intervals(char, int, int, int, MDESC*, MDESC*, int, int, int, int, IDESC*);
+extern void Cpdgemr2do(int, int, double*, int, int, MDESC*, double*, int, int, MDESC*);
+extern void Cpdgemr2d(int, int, double*, int, int, MDESC*, double*, int, int, MDESC*, int);
 /* some defines for Cpdgemr2do */
 #define SENDBUFF 0
 #define RECVBUFF 1
@@ -243,42 +243,42 @@ extern void Cpdgemr2d();
 #include <assert.h>
 #define DESCLEN 9
 void 
-fortran_mr2d(m, n, A, ia, ja, desc_A,
-	     B, ib, jb, desc_B)
-  int  *ia, *ib, *ja, *jb, *m, *n;
-  int   desc_A[DESCLEN], desc_B[DESCLEN];
-  double *A, *B;
+fortran_mr2d(int *m, int *n, double *A, int *ia, int *ja, int desc_A[DESCLEN],
+	     double *B, int *ib, int *jb, int desc_B[DESCLEN])
+//WCC  int  *ia, *ib, *ja, *jb, *m, *n;
+//WCC  int   desc_A[DESCLEN], desc_B[DESCLEN];
+//WCC  double *A, *B;
 {
   Cpdgemr2do(*m, *n, A, *ia, *ja, (MDESC *) desc_A,
 	     B, *ib, *jb, (MDESC *) desc_B);
   return;
 }
 void 
-fortran_mr2dnew(m, n, A, ia, ja, desc_A,
-		B, ib, jb, desc_B, gcontext)
-  int  *ia, *ib, *ja, *jb, *m, *n;
-  int   desc_A[DESCLEN], desc_B[DESCLEN];
-  double *A, *B;
-  int  *gcontext;
+fortran_mr2dnew(int *m, int *n, double *A, int *ia, int *ja, int desc_A[DESCLEN],
+		double *B, int *ib, int *jb, int desc_B[DESCLEN], int *gcontext)
+//WCC  int  *ia, *ib, *ja, *jb, *m, *n;
+//WCC  int   desc_A[DESCLEN], desc_B[DESCLEN];
+//WCC  double *A, *B;
+//WCC  int  *gcontext;
 {
   Cpdgemr2d(*m, *n, A, *ia, *ja, (MDESC *) desc_A,
 	    B, *ib, *jb, (MDESC *) desc_B, *gcontext);
   return;
 }
-static2 void init_chenille();
-static2 int inter_len();
-static2 int block2buff();
-static2 void buff2block();
-static2 void gridreshape();
+static2 void init_chenille(int, int, int, int*, int, int*, int**, int**, int*);
+static2 int inter_len(int, IDESC*, int, IDESC*);
+static2 int block2buff(IDESC*, int, IDESC*, int, double*, MDESC*, double*);
+static2 void buff2block(IDESC*, int, IDESC*, int, double*, double*, MDESC*);
+static2 void gridreshape(int*);
 void
-Cpdgemr2do(m, n,
-	   ptrmyblock, ia, ja, ma,
-	   ptrmynewblock, ib, jb, mb)
-  double *ptrmyblock, *ptrmynewblock;
+Cpdgemr2do(int m, int n,
+	   double *ptrmyblock, int ia, int ja, MDESC *ma,
+	   double *ptrmynewblock, int ib, int jb, MDESC *mb)
+//WCC  double *ptrmyblock, *ptrmynewblock;
 /* pointers to the memory location of the matrix and the redistributed matrix */
-  MDESC *ma;
-  MDESC *mb;
-  int   ia, ja, ib, jb, m, n;
+//WCC  MDESC *ma;
+//WCC  MDESC *mb;
+//WCC  int   ia, ja, ib, jb, m, n;
 {
   int   dummy, nprocs;
   int   gcontext;
@@ -295,14 +295,14 @@ Cpdgemr2do(m, n,
 			 * idem B puis ia,ja puis ib,jb */
 #define MAGIC_MAX 100000000
 void
-Cpdgemr2d(m, n,
-	  ptrmyblock, ia, ja, ma,
-	  ptrmynewblock, ib, jb, mb, globcontext)
-  double *ptrmyblock, *ptrmynewblock;
+Cpdgemr2d(int m, int n,
+	  double *ptrmyblock, int ia, int ja, MDESC *ma,
+	  double *ptrmynewblock, int ib, int jb, MDESC *mb, int globcontext)
+//WCC  double *ptrmyblock, *ptrmynewblock;
 /* pointers to the memory location of the matrix and the redistributed matrix */
-  MDESC *ma;
-  MDESC *mb;
-  int   ia, ja, ib, jb, m, n, globcontext;
+//WCC  MDESC *ma;
+//WCC  MDESC *mb;
+//WCC  int   ia, ja, ib, jb, m, n, globcontext;
 {
   double *ptrsendbuff, *ptrrecvbuff, *ptrNULL = 0;
   double *recvptr;
@@ -565,10 +565,10 @@ after_comm:
   }	/* { int tot,nr,ns ...} */
   /* don't forget to clean up things! */
   if (myprow1 >= 0 && mypcol1 >= 0) {
-    freememory((char *) ptrrecvbuff);
+    freememory((double *) ptrrecvbuff);
   };
   if (myprow0 >= 0 && mypcol0 >= 0) {
-    freememory((char *) ptrsendbuff);
+    freememory((double *) ptrsendbuff);
   };
   if (nprow != 1)
     Cblacs_gridexit(gcontext);
@@ -577,9 +577,9 @@ after_comm:
   free(param);
 }/* distrib */
 static2 void 
-init_chenille(mypnum, nprocs, n0, proc0, n1, proc1, psend, precv, myrang)
-  int   nprocs, mypnum, n0, n1;
-  int  *proc0, *proc1, **psend, **precv, *myrang;
+init_chenille(int mypnum, int nprocs, int n0, int *proc0, int n1, int *proc1, int **psend, int **precv, int *myrang)
+//WCC  int   nprocs, mypnum, n0, n1;
+//WCC  int  *proc0, *proc1, **psend, **precv, *myrang;
 {
   int   ns, nr, i, tot;
   int  *sender, *recver, *g0, *g1;
@@ -650,11 +650,11 @@ int _m,_n,_lda,_ldb; \
     } \
 }
 static2 int 
-block2buff(vi, vinb, hi, hinb, ptra, ma, buff)
-  int   hinb, vinb;
-  IDESC *hi, *vi;
-  MDESC *ma;
-  double *buff, *ptra;
+block2buff(IDESC *vi, int vinb, IDESC *hi, int hinb, double *ptra, MDESC *ma, double *buff)
+//WCC  int   hinb, vinb;
+//WCC  IDESC *hi, *vi;
+//WCC  MDESC *ma;
+//WCC  double *buff, *ptra;
 {
   int   h, v, sizebuff;
   double *ptr2;
@@ -672,11 +672,11 @@ block2buff(vi, vinb, hi, hinb, ptra, ma, buff)
   return sizebuff;
 }
 static2 void 
-buff2block(vi, vinb, hi, hinb, buff, ptrb, mb)
-  int   hinb, vinb;
-  IDESC *hi, *vi;
-  MDESC *mb;
-  double *buff, *ptrb;
+buff2block(IDESC *vi, int vinb, IDESC *hi, int hinb, double *buff, double *ptrb, MDESC *mb)
+//WCC  int   hinb, vinb;
+//WCC  IDESC *hi, *vi;
+//WCC  MDESC *mb;
+//WCC  double *buff, *ptrb;
 {
   int   h, v, sizebuff;
   double *ptr2;
@@ -693,9 +693,9 @@ buff2block(vi, vinb, hi, hinb, buff, ptrb, mb)
   }
 }
 static2 int 
-inter_len(hinb, hi, vinb, vi)
-  int   hinb, vinb;
-  IDESC *hi, *vi;
+inter_len(int hinb, IDESC *hi, int vinb, IDESC *vi)
+//WCC  int   hinb, vinb;
+//WCC  IDESC *hi, *vi;
 {
   int   hlen, vlen, h, v;
   hlen = 0;
@@ -707,9 +707,9 @@ inter_len(hinb, hi, vinb, vi)
   return hlen * vlen;
 }
 void 
-Clacpy(m, n, a, lda, b, ldb)
-  double *a, *b;
-  int   m, n, lda, ldb;
+Clacpy(int m, int n, double *a, int lda, double *b, int ldb)
+//WCC  double *a, *b;
+//WCC  int   m, n, lda, ldb;
 {
   int   i, j;
   lda -= m;
@@ -723,8 +723,8 @@ Clacpy(m, n, a, lda, b, ldb)
   }
 }
 static2 void 
-gridreshape(ctxtp)
-  int  *ctxtp;
+gridreshape(int *ctxtp)
+//WCC  int  *ctxtp;
 {
   int   ori, final;	/* original context, and new context created, with
 			 * line form */
